@@ -1,5 +1,5 @@
 /* Conversion to and from ARMSCII-8
-   Copyright (C) 1997-1999, 2000-2002 Free Software Foundation, Inc.
+   Copyright (C) 1997-2019 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
    Contributed by Ulrich Drepper <drepper@cygnus.com>, 1997.
 
@@ -14,9 +14,8 @@
    Lesser General Public License for more details.
 
    You should have received a copy of the GNU Lesser General Public
-   License along with the GNU C Library; if not, write to the Free
-   Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
-   02111-1307 USA.  */
+   License along with the GNU C Library; if not, see
+   <http://www.gnu.org/licenses/>.  */
 
 #include <dlfcn.h>
 #include <stdint.h>
@@ -29,6 +28,7 @@
 #define DEFINE_FINI		1
 #define MIN_NEEDED_FROM		1
 #define MIN_NEEDED_TO		4
+#define ONE_DIRECTION		0
 
 
 static const uint16_t map_from_armscii_8[0xfe - 0xa2 + 1] =
@@ -57,11 +57,17 @@ static const uint16_t map_from_armscii_8[0xfe - 0xa2 + 1] =
     uint_fast8_t ch = *inptr;						      \
 									      \
     if (ch <= 0xa0)							      \
-      /* Upto and including 0xa0 the ARMSCII-8 corresponds to Unicode.  */    \
-      *((uint32_t *) outptr)++ = ch;					      \
+      {									      \
+        /* Upto and including 0xa0 the ARMSCII-8 corresponds to Unicode.  */  \
+        *((uint32_t *) outptr) = ch;					      \
+        outptr += sizeof (uint32_t);					      \
+      }									      \
     else if (ch >= 0xa2 && ch <= 0xfe)					      \
-      /* Use the table.  */						      \
-      *((uint32_t *) outptr)++ = map_from_armscii_8[ch - 0xa2];		      \
+      {									      \
+        /* Use the table.  */						      \
+        *((uint32_t *) outptr) = map_from_armscii_8[ch - 0xa2];		      \
+        outptr += sizeof (uint32_t);					      \
+      }									      \
     else								      \
       {									      \
 	/* This is an illegal character.  */				      \
