@@ -1,5 +1,5 @@
 /* Mapping table for IBM1160.
-   Copyright (C) 2001 Free Software Foundation, Inc.
+   Copyright (C) 2001-2019 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
    Contributed by Masahide Washizawa <washi@jp.ibm.com>, 2001.
 
@@ -14,9 +14,10 @@
    Lesser General Public License for more details.
 
    You should have received a copy of the GNU Lesser General Public
-   License along with the GNU C Library; if not, write to the Free
-   Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
-   02111-1307 USA.  */
+   License along with the GNU C Library; if not, see
+   <http://www.gnu.org/licenses/>.  */
+
+#include <stdint.h>
 
 static const uint32_t to_ucs4[256] =
 {
@@ -88,10 +89,10 @@ static const uint32_t to_ucs4[256] =
 
 static const struct gap from_idx[] =
 {
-  { start: 0x0000, end: 0x00ac, idx:     0 },
-  { start: 0x0e01, end: 0x0e5b, idx: -3412 },
-  { start: 0x20ac, end: 0x20ac, idx: -8100 },
-  { start: 0xffff, end: 0xffff, idx:     0 }
+  { .start = 0x0000, .end = 0x00ac, .idx =     0 },
+  { .start = 0x0e01, .end = 0x0e5b, .idx = -3412 },
+  { .start = 0x20ac, .end = 0x20ac, .idx = -8100 },
+  { .start = 0xffff, .end = 0xffff, .idx =     0 }
 };
 
 static const char from_ucs4[] =
