@@ -1,4 +1,4 @@
-/* Copyright (C) 1995, 1996, 1997 Free Software Foundation, Inc.
+/* Copyright (C) 1995-2019 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
    The GNU C Library is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
 #include "stdio.h"
 
 void
-clearerr (fp)
-     FILE *fp;
+clearerr (FILE *fp)
 {
   CHECK_FILE (fp, /*nothing*/);
   _IO_flockfile (fp);
@@ -28,6 +27,6 @@ clearerr (fp)
   _IO_funlockfile (fp);
 }
 
-#if defined weak_alias && !defined _IO_MTSAFE_IO
+#ifndef _IO_MTSAFE_IO
 weak_alias (clearerr, clearerr_unlocked)
 #endif
