@@ -1,4 +1,4 @@
-/* Copyright (C) 1993-2018 Free Software Foundation, Inc.
+/* Copyright (C) 1993-2019 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
    The GNU C Library is free software; you can redistribute it and/or
@@ -28,7 +28,7 @@
 #include <stdio.h>
 
 int
-__fflush_unlocked (_IO_FILE *fp)
+__fflush_unlocked (FILE *fp)
 {
   if (fp == NULL)
     return _IO_flush_all ();
