@@ -1,4 +1,4 @@
-/* Copyright (C) 1996, 1997 Free Software Foundation, Inc.
+/* Copyright (C) 1996-2019 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
    Contributed by Ulrich Drepper <drepper@cygnus.com>
    and Paul Janzen <pcj@primenet.com>, 1996.
@@ -14,22 +14,18 @@
    Lesser General Public License for more details.
 
    You should have received a copy of the GNU Lesser General Public
-   License along with the GNU C Library; if not, write to the Free
-   Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
-   02111-1307 USA.  */
+   License along with the GNU C Library; if not, see
+   <http://www.gnu.org/licenses/>.  */
 
 #include <errno.h>
-#include <bits/libc-lock.h>
+#include <libc-lock.h>
 #include <utmp.h>
 
 #include "utmp-private.h"
 
 
 /* We have to use the lock in getutent_r.c.  */
-__libc_lock_define (extern, __libc_utmp_lock)
-
-/* The jump table is also in getutent_r.c.  */
-extern struct utfuncs *__libc_utmp_jump_table;
+__libc_lock_define (extern, __libc_utmp_lock attribute_hidden)
 
 
 int
@@ -46,4 +42,5 @@ __getutline_r (const struct utmp *line, struct utmp *buffer,
 
   return retval;
 }
+libc_hidden_def (__getutline_r)
 weak_alias (__getutline_r, getutline_r)
