@@ -1,5 +1,5 @@
 /* Return positive difference between arguments.
-   Copyright (C) 1997-2018 Free Software Foundation, Inc.
+   Copyright (C) 1997-2019 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
    Contributed by Ulrich Drepper <drepper@cygnus.com>, 1997.
 
@@ -19,7 +19,7 @@
 
 #include <errno.h>
 #include <math.h>
-#include <math_private.h>
+#include <math-narrow-eval.h>
 
 FLOAT
 M_DECL_FUNC (__fdim) (FLOAT x, FLOAT y)
