@@ -1,4 +1,4 @@
-/* Copyright (C) 2002, 2003 Free Software Foundation, Inc.
+/* Copyright (C) 2002-2019 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
    Contributed by Ulrich Drepper <drepper@redhat.com>, 2002.
 
@@ -16,15 +16,12 @@
    License along with the GNU C Library; if not, see
    <http://www.gnu.org/licenses/>.  */
 
-#include <assert.h>
 #include <errno.h>
 #include "pthreadP.h"
 
 
 int
-__pthread_attr_setstackaddr (attr, stackaddr)
-     pthread_attr_t *attr;
-     void *stackaddr;
+__pthread_attr_setstackaddr (pthread_attr_t *attr, void *stackaddr)
 {
   struct pthread_attr *iattr;
 
@@ -32,7 +29,6 @@ __pthread_attr_setstackaddr (attr, stackaddr)
   EXTRA_PARAM_CHECKS;
 #endif
 
-  assert (sizeof (*attr) >= sizeof (struct pthread_attr));
   iattr = (struct pthread_attr *) attr;
 
   iattr->stackaddr = stackaddr;
