@@ -1,4 +1,4 @@
-/* Copyright (C) 1991-2018 Free Software Foundation, Inc.
+/* Copyright (C) 1991-2019 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
    The GNU C Library is free software; you can redistribute it and/or
@@ -827,32 +827,31 @@ __glob (const char *pattern, int flags, int (*errfunc) (const char *, int),
 	      {
 		size_t home_len = strlen (p->pw_dir);
 		size_t rest_len = end_name == NULL ? 0 : strlen (end_name);
-		char *d, *newp;
-		bool use_alloca = glob_use_alloca (alloca_used,
-						   home_len + rest_len + 1);
+		char *d;
 
-		if (use_alloca)
-		  newp = alloca_account (home_len + rest_len + 1, alloca_used);
+		if (__glibc_unlikely (malloc_dirname))
+		  free (dirname);
+		malloc_dirname = 0;
+
+		if (glob_use_alloca (alloca_used, home_len + rest_len + 1))
+		  dirname = alloca_account (home_len + rest_len + 1,
+					    alloca_used);
 		else
 		  {
-		    newp = malloc (home_len + rest_len + 1);
-		    if (newp == NULL)
+		    dirname = malloc (home_len + rest_len + 1);
+		    if (dirname == NULL)
 		      {
 			scratch_buffer_free (&pwtmpbuf);
 			retval = GLOB_NOSPACE;
 			goto out;
 		      }
+		    malloc_dirname = 1;
 		  }
-		d = mempcpy (newp, p->pw_dir, home_len);
+		d = mempcpy (dirname, p->pw_dir, home_len);
 		if (end_name != NULL)
 		  d = mempcpy (d, end_name, rest_len);
 		*d = '\0';
 
-		if (__glibc_unlikely (malloc_dirname))
-		  free (dirname);
-		dirname = newp;
-		malloc_dirname = !use_alloca;
-
 		dirlen = home_len + rest_len;
 		dirname_modified = 1;
 	      }
