@@ -1,4 +1,4 @@
-/* Copyright (C) 1997-2018 Free Software Foundation, Inc.
+/* Copyright (C) 1997-2019 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
    The GNU C Library is free software; you can redistribute it and/or
@@ -200,7 +200,6 @@ struct test_case_struct
     { 0, NULL, "$var", 0, 0, { NULL, }, IFS },
     { 0, NULL, "\"\\n\"", 0, 1, { "\\n", }, IFS },
     { 0, NULL, "", 0, 0, { NULL, }, IFS },
-    { 0, NULL, "${1234567890123456789012}", 0, 0, { NULL, }, IFS },
 
     /* Flags not already covered (testit() has special handling for these) */
     { 0, NULL, "one two", WRDE_DOOFFS, 2, { "one", "two", }, IFS },
@@ -509,8 +508,8 @@ testit (struct test_case_struct *tc)
 	  }
 
       for (i = 0; i < we.we_wordc; ++i)
-	if (we.we_wordv[i+start_offs] == NULL ||
-	    strcmp (tc->wordv[i], we.we_wordv[i+start_offs]) != 0)
+	if (we.we_wordv[i+start_offs] == NULL
+	    || strcmp (tc->wordv[i], we.we_wordv[i+start_offs]) != 0)
 	  {
 	    bzzzt = 1;
 	    break;
@@ -535,10 +534,10 @@ testit (struct test_case_struct *tc)
 	}
       printf ("\n");
     }
-  else if (retval != 0 && retval != WRDE_NOSPACE &&
-	   (we.we_wordc != sav_we.we_wordc ||
-            we.we_wordv != sav_we.we_wordv ||
-            we.we_offs != sav_we.we_offs))
+  else if (retval != 0 && retval != WRDE_NOSPACE
+	   && (we.we_wordc != sav_we.we_wordc
+	       || we.we_wordv != sav_we.we_wordv
+	       || we.we_offs != sav_we.we_offs))
     {
       bzzzt = 1;
       printf ("FAILED to restore wordexp_t members\n");
