@@ -1,4 +1,4 @@
-/* Copyright (C) 1995-2015 Free Software Foundation, Inc.
+/* Copyright (C) 1995-2019 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
    Contributed by Ulrich Drepper <drepper@gnu.ai.mit.edu>, August 1995.
 
@@ -22,9 +22,7 @@
 #include <limits.h>
 
 int
-__lcong48_r (param, buffer)
-     unsigned short int param[7];
-     struct drand48_data *buffer;
+__lcong48_r (unsigned short int param[7], struct drand48_data *buffer)
 {
   /* Store the given values.  */
   memcpy (buffer->__x, &param[0], sizeof (buffer->__x));
