@@ -1,4 +1,4 @@
-/* Copyright (C) 1991-2013 Free Software Foundation, Inc.
+/* Copyright (C) 1991-2019 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
    The GNU C Library is free software; you can redistribute it and/or
@@ -22,12 +22,7 @@
 
 /* Convert the string of multibyte characters in S to `wchar_t's in
    PWCS, writing no more than N.  Return the number written,
-   or (size_t) -1 if an invalid multibyte character is encountered.
-
-   Attention: this function should NEVER be intentionally used.
-   The interface is completely stupid.  The state is shared between
-   all conversion functions.  You should use instead the restartable
-   version `mbsrtowcs'.  */
+   or (size_t) -1 if an invalid multibyte character is encountered.  */
 size_t
 mbstowcs (wchar_t *pwcs, const char *s, size_t n)
 {
