@@ -1,4 +1,4 @@
-/* Copyright (C) 1991-2014 Free Software Foundation, Inc.
+/* Copyright (C) 1991-2019 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
    The GNU C Library is free software; you can redistribute it and/or
@@ -20,7 +20,7 @@
 #include <stdlib.h>
 #include <string.h>
 #include <libintl.h>
-#include <bits/libc-lock.h>
+#include <libc-lock.h>
 
 static __libc_key_t key;
 
