@@ -46,6 +46,7 @@
 #include <libintl.h>
 #include <sys/param.h>
 #include <wchar.h>
+#include <shlib-compat.h>
 
 #include <rpc/types.h>
 #include <rpc/xdr.h>
@@ -82,7 +83,7 @@ struct audata {
 };
 #define	AUTH_PRIVATE(auth)	((struct audata *)auth->ah_private)
 
-static bool_t marshal_new_auth (AUTH *) internal_function;
+static bool_t marshal_new_auth (AUTH *);
 
 
 /*
@@ -149,7 +150,7 @@ no_memory:
   marshal_new_auth (auth);
   return auth;
 }
-libc_hidden_nolink (authunix_create, GLIBC_2_0)
+libc_hidden_nolink_sunrpc (authunix_create, GLIBC_2_0)
 
 /*
  * Returns an auth handle with parameters determined by doing lots of
@@ -216,7 +217,7 @@ authunix_create_default (void)
 #ifdef EXPORT_RPC_SYMBOLS
 libc_hidden_def (authunix_create_default)
 #else
-libc_hidden_nolink (authunix_create_default, GLIBC_2_0)
+libc_hidden_nolink_sunrpc (authunix_create_default, GLIBC_2_0)
 #endif
 
 /*
@@ -336,7 +337,6 @@ authunix_destroy (AUTH *auth)
  * sets private data, au_marshed and au_mpos
  */
 static bool_t
-internal_function
 marshal_new_auth (AUTH *auth)
 {
   XDR xdr_stream;
