@@ -1,4 +1,4 @@
-/* Copyright (C) 1998-2015 Free Software Foundation, Inc.
+/* Copyright (C) 1998-2019 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
    Contributed by Mark Kettenis <kettenis@phys.uva.nl>, 1998.
 
@@ -19,11 +19,13 @@
 #include <string.h>
 #include <unistd.h>
 
-#define TRANSFORM_UTMP_FILE_NAME(file_name) \
-    ((strcmp (file_name, _PATH_UTMP "x") == 0 \
-      && __access (_PATH_UTMP "x", F_OK) != 0) ? _PATH_UTMP : \
-     ((strcmp (file_name, _PATH_WTMP "x") == 0 \
-       && __access (_PATH_WTMP "x", F_OK) != 0) ? _PATH_WTMP : \
-      file_name))
+#define TRANSFORM_UTMP_FILE_NAME(file_name)	\
+  ((strcmp (file_name, _PATH_UTMP "x") == 0	\
+    && __access (_PATH_UTMP "x", F_OK) != 0)	\
+   ? _PATH_UTMP					\
+   : ((strcmp (file_name, _PATH_WTMP "x") == 0	\
+       && __access (_PATH_WTMP "x", F_OK) != 0)	\
+      ? _PATH_WTMP				\
+      : file_name))
 
 #include <login/updwtmp.c>
