@@ -1,5 +1,5 @@
 /* Compute remainder and a congruent to the quotient.
-   Copyright (C) 1997-2017 Free Software Foundation, Inc.
+   Copyright (C) 1997-2019 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
    Contributed by Ulrich Drepper <drepper@cygnus.com>, 1997 and
 		  Jakub Jelinek <jj@ultra.linux.cz>, 1999.
@@ -31,7 +31,7 @@ long double
 __remquol (long double x, long double y, int *quo)
 {
   int64_t hx,hy;
-  u_int64_t sx,lx,ly,qs;
+  uint64_t sx,lx,ly,qs;
   int cquo;
   double xhi, xlo, yhi, ylo;
 
