@@ -1,5 +1,5 @@
 /* Operating system support for run-time dynamic linker.  Hurd version.
-   Copyright (C) 1995,96,97,98,99,2000,2001 Free Software Foundation, Inc.
+   Copyright (C) 1995-2019 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
    The GNU C Library is free software; you can redistribute it and/or
@@ -13,9 +13,12 @@
    Lesser General Public License for more details.
 
    You should have received a copy of the GNU Lesser General Public
-   License along with the GNU C Library; if not, write to the Free
-   Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
-   02111-1307 USA.  */
+   License along with the GNU C Library; if not, see
+   <http://www.gnu.org/licenses/>.  */
+
+/* In the static library, this is all handled by dl-support.c
+   or by the vanilla definitions in the rest of the C library.  */
+#ifdef SHARED
 
 #include <hurd.h>
 #include <link.h>
@@ -28,6 +31,7 @@
 #include <assert.h>
 #include <sysdep.h>
 #include <mach/mig_support.h>
+#include <mach/machine/vm_param.h>
 #include "hurdstartup.h"
 #include <hurd/lookup.h>
 #include <hurd/auth.h>
@@ -41,46 +45,44 @@
 #include <dl-machine.h>
 #include <dl-procinfo.h>
 
+#include <dl-tunables.h>
+#include <not-errno.h>
+
 extern void __mach_init (void);
 
 extern int _dl_argc;
 extern char **_dl_argv;
 extern char **_environ;
 
-int __libc_enable_secure;
+int __libc_enable_secure = 0;
+rtld_hidden_data_def (__libc_enable_secure)
 int __libc_multiple_libcs = 0;	/* Defining this here avoids the inclusion
 				   of init-first.  */
-/* This variable containts the lowest stack address ever used.  */
-void *__libc_stack_end;
-unsigned long int _dl_hwcap_mask = HWCAP_IMPORTANT;
+/* This variable contains the lowest stack address ever used.  */
+void *__libc_stack_end = NULL;
+rtld_hidden_data_def(__libc_stack_end)
 
+/* TODO: Initialize.  */
+void *_dl_random attribute_relro = NULL;
 
 struct hurd_startup_data *_dl_hurd_data;
 
-/* Defining these variables here avoids the inclusion of hurdsig.c.  */
-unsigned long int __hurd_sigthread_stack_base;
-unsigned long int __hurd_sigthread_stack_end;
-unsigned long int *__hurd_sigthread_variables;
-
-/* Defining these variables here avoids the inclusion of init-first.c.
-   We need to provide temporary storage for the per-thread variables
-   of the main user thread here, since it is used for storing the
-   `errno' variable.  Note that this information is lost once we
-   relocate the dynamic linker.  */
-static unsigned long int threadvars[_HURD_THREADVAR_MAX];
-unsigned long int __hurd_threadvar_stack_offset
-  = (unsigned long int) &threadvars;
-unsigned long int __hurd_threadvar_stack_mask;
-
+#define FMH defined(__i386__)
+#if ! FMH
+# define fmh()		((void)0)
+# define unfmh()	((void)0)
+#else
 /* XXX loser kludge for vm_map kernel bug */
+#undef	ELF_MACHINE_USER_ADDRESS_MASK
+#define ELF_MACHINE_USER_ADDRESS_MASK	0
 static vm_address_t fmha;
 static vm_size_t fmhs;
 static void unfmh(void){
 __vm_deallocate(__mach_task_self(),fmha,fmhs);}
 static void fmh(void) {
-    error_t err;int x;mach_port_t p;
+    error_t err;int x;vm_offset_t o;mach_port_t p;
     vm_address_t a=0x08000000U,max=VM_MAX_ADDRESS;
-    while (!(err=__vm_region(__mach_task_self(),&a,&fmhs,&x,&x,&x,&x,&p,&x))){
+    while (!(err=__vm_region(__mach_task_self(),&a,&fmhs,&x,&x,&x,&x,&p,&o))){
       __mach_port_deallocate(__mach_task_self(),p);
       if (a+fmhs>=0x80000000U){
 	max=a; break;}
@@ -94,17 +96,17 @@ static void fmh(void) {
     assert_perror(err);}
   }
 /* XXX loser kludge for vm_map kernel bug */
+#endif
 
 
-
-Elf32_Addr
+ElfW(Addr)
 _dl_sysdep_start (void **start_argptr,
-		  void (*dl_main) (const Elf32_Phdr *phdr, Elf32_Word phent,
-				   Elf32_Addr *user_entry))
+		  void (*dl_main) (const ElfW(Phdr) *phdr, ElfW(Word) phent,
+				   ElfW(Addr) *user_entry,
+				   ElfW(auxv_t) *auxv))
 {
-  void go (int *argdata)
+  void go (intptr_t *argdata)
     {
-      extern unsigned int _dl_skip_args; /* rtld.c */
       char **p;
 
       /* Cache the information in various global variables.  */
@@ -124,8 +126,10 @@ _dl_sysdep_start (void **start_argptr,
 
       __libc_enable_secure = _dl_hurd_data->flags & EXEC_SECURE;
 
-      if (_dl_hurd_data->flags & EXEC_STACK_ARGS &&
-	  _dl_hurd_data->user_entry == 0)
+      __tunables_init (_environ);
+
+      if (_dl_hurd_data->flags & EXEC_STACK_ARGS
+	  && _dl_hurd_data->user_entry == 0)
 	_dl_hurd_data->user_entry = (vm_address_t) ENTRY_POINT;
 
 unfmh();			/* XXX */
@@ -168,7 +172,7 @@ unfmh();			/* XXX */
 	    assert_perror (err);
 
 	    lastslash = strrchr (p, '/');
-	    l = _dl_map_object_from_fd (lastslash ? lastslash + 1 : p,
+	    l = _dl_map_object_from_fd (lastslash ? lastslash + 1 : p, NULL,
 					memobj, strdup (p), 0);
 
 	    /* Squirrel away the memory object port where it
@@ -179,9 +183,9 @@ unfmh();			/* XXX */
 
       /* Call elf/rtld.c's main program.  It will set everything
 	 up and leave us to transfer control to USER_ENTRY.  */
-      (*dl_main) ((const Elf32_Phdr *) _dl_hurd_data->phdr,
-		  _dl_hurd_data->phdrsz / sizeof (Elf32_Phdr),
-		  &_dl_hurd_data->user_entry);
+      (*dl_main) ((const ElfW(Phdr) *) _dl_hurd_data->phdr,
+		  _dl_hurd_data->phdrsz / sizeof (ElfW(Phdr)),
+		  (ElfW(Addr) *) &_dl_hurd_data->user_entry, NULL);
 
       /* The call above might screw a few things up.
 
@@ -236,7 +240,7 @@ unfmh();			/* XXX */
   __mach_init ();
 
   /* Initialize frequently used global variable.  */
-  _dl_pagesize = __getpagesize ();
+  GLRO(dl_pagesize) = __getpagesize ();
 
 fmh();				/* XXX */
 
@@ -250,26 +254,36 @@ fmh();				/* XXX */
 }
 
 void
-internal_function
 _dl_sysdep_start_cleanup (void)
 {
   /* Deallocate the reply port and task port rights acquired by
      __mach_init.  We are done with them now, and the user will
      reacquire them for himself when he wants them.  */
   __mig_dealloc_reply_port (MACH_PORT_NULL);
+  __mach_port_deallocate (__mach_task_self (), __mach_host_self_);
   __mach_port_deallocate (__mach_task_self (), __mach_task_self_);
 }
 
 /* Minimal open/close/mmap implementation sufficient for initial loading of
    shared libraries.  These are weak definitions so that when the
    dynamic linker re-relocates itself to be user-visible (for -ldl),
-   it will get the user's definition (i.e. usually libc's).  */
+   it will get the user's definition (i.e. usually libc's).
+
+   They also need to be set in the ld section of sysdeps/mach/hurd/Versions, to
+   be overridable, and in libc.abilist and ld.abilist to be checked. */
+
+/* This macro checks that the function does not get renamed to be hidden: we do
+   need these to be overridable by libc's.  */
+#define check_no_hidden(name)				\
+  __typeof (name) __check_##name##_no_hidden		\
+       __attribute__ ((alias (#name)))			\
+       __attribute_copy__ (name);
 
 /* Open FILE_NAME and return a Hurd I/O for it in *PORT, or return an
    error.  If STAT is non-zero, stat the file into that stat buffer.  */
 static error_t
 open_file (const char *file_name, int flags,
-	   mach_port_t *port, struct stat *stat)
+	   mach_port_t *port, struct stat64 *stat)
 {
   enum retry_type doretry;
   char retryname[1024];		/* XXX string_t LOSES! */
@@ -295,10 +309,10 @@ open_file (const char *file_name, int flags,
       return MACH_PORT_NULL;
     }
 
-  assert (!(flags & ~O_READ));
+  assert (!(flags & ~(O_READ | O_CLOEXEC)));
 
-  startdir = _dl_hurd_data->portarray[file_name[0] == '/' ?
-				      INIT_PORT_CRDIR : INIT_PORT_CWDIR];
+  startdir = _dl_hurd_data->portarray[file_name[0] == '/'
+				      ? INIT_PORT_CRDIR : INIT_PORT_CWDIR];
 
   while (file_name[0] == '/')
     file_name++;
@@ -320,6 +334,8 @@ open_file (const char *file_name, int flags,
   return err;
 }
 
+check_no_hidden(__open);
+check_no_hidden (__open64);
 int weak_function
 __open (const char *file_name, int mode, ...)
 {
@@ -330,7 +346,9 @@ __open (const char *file_name, int mode, ...)
   else
     return (int)port;
 }
+weak_alias (__open, __open64)
 
+check_no_hidden(__close);
 int weak_function
 __close (int fd)
 {
@@ -339,14 +357,16 @@ __close (int fd)
   return 0;
 }
 
+check_no_hidden(__read);
 __ssize_t weak_function
-__libc_read (int fd, void *buf, size_t nbytes)
+__read (int fd, void *buf, size_t nbytes)
 {
   error_t err;
   char *data;
   mach_msg_type_number_t nread;
 
   data = buf;
+  nread = nbytes;
   err = __io_read ((mach_port_t) fd, &data, &nread, -1, nbytes);
   if (err)
     return __hurd_fail (err);
@@ -359,9 +379,11 @@ __libc_read (int fd, void *buf, size_t nbytes)
 
   return nread;
 }
+libc_hidden_weak (__read)
 
+check_no_hidden(__write);
 __ssize_t weak_function
-__libc_write (int fd, const void *buf, size_t nbytes)
+__write (int fd, const void *buf, size_t nbytes)
 {
   error_t err;
   mach_msg_type_number_t nwrote;
@@ -374,18 +396,24 @@ __libc_write (int fd, const void *buf, size_t nbytes)
 
   return nwrote;
 }
+libc_hidden_weak (__write)
 
 /* This is only used for printing messages (see dl-misc.c).  */
+check_no_hidden(__writev);
 __ssize_t weak_function
 __writev (int fd, const struct iovec *iov, int niov)
 {
+  if (fd >= _hurd_init_dtablesize)
+    {
+      errno = EBADF;
+      return -1;
+    }
+
   int i;
   size_t total = 0;
   for (i = 0; i < niov; ++i)
     total += iov[i].iov_len;
 
-  assert (fd < _hurd_init_dtablesize);
-
   if (total != 0)
     {
       char buf[total], *bufp = buf;
@@ -405,9 +433,9 @@ __writev (int fd, const struct iovec *iov, int niov)
   return 0;
 }
 
-
-off_t weak_function
-__lseek (int fd, off_t offset, int whence)
+check_no_hidden(__libc_lseek64);
+off64_t weak_function
+__libc_lseek64 (int fd, off64_t offset, int whence)
 {
   error_t err;
 
@@ -418,8 +446,9 @@ __lseek (int fd, off_t offset, int whence)
   return offset;
 }
 
-__ptr_t weak_function
-__mmap (__ptr_t addr, size_t len, int prot, int flags, int fd, off_t offset)
+check_no_hidden(__mmap);
+void *weak_function
+__mmap (void *addr, size_t len, int prot, int flags, int fd, off_t offset)
 {
   error_t err;
   vm_prot_t vmprot;
@@ -441,13 +470,14 @@ __mmap (__ptr_t addr, size_t len, int prot, int flags, int fd, off_t offset)
       assert (!(flags & MAP_SHARED));
       err = __io_map ((mach_port_t) fd, &memobj_rd, &memobj_wr);
       if (err)
-	return (__ptr_t) __hurd_fail (err);
-      __mach_port_deallocate (__mach_task_self (), memobj_wr);
+	return __hurd_fail (err), MAP_FAILED;
+      if (memobj_wr != MACH_PORT_NULL)
+	__mach_port_deallocate (__mach_task_self (), memobj_wr);
     }
 
   mapaddr = (vm_address_t) addr;
   err = __vm_map (__mach_task_self (),
-		  &mapaddr, (vm_size_t) len, 0 /*ELF_MACHINE_USER_ADDRESS_MASK*/,
+		  &mapaddr, (vm_size_t) len, ELF_MACHINE_USER_ADDRESS_MASK,
 		  !(flags & MAP_FIXED),
 		  memobj_rd,
 		  (vm_offset_t) offset,
@@ -461,7 +491,8 @@ __mmap (__ptr_t addr, size_t len, int prot, int flags, int fd, off_t offset)
       err = __vm_deallocate (__mach_task_self (), mapaddr, len);
       if (! err)
 	err = __vm_map (__mach_task_self (),
-			&mapaddr, (vm_size_t) len, 0 /*ELF_MACHINE_USER_ADDRESS_MASK*/,
+			&mapaddr, (vm_size_t) len,
+			ELF_MACHINE_USER_ADDRESS_MASK,
 			!(flags & MAP_FIXED),
 			memobj_rd, (vm_offset_t) offset,
 			flags & (MAP_COPY|MAP_PRIVATE),
@@ -473,11 +504,14 @@ __mmap (__ptr_t addr, size_t len, int prot, int flags, int fd, off_t offset)
   if ((flags & MAP_ANON) == 0)
     __mach_port_deallocate (__mach_task_self (), memobj_rd);
 
-  return err ? (__ptr_t) __hurd_fail (err) : (__ptr_t) mapaddr;
+  if (err)
+    return __hurd_fail (err), MAP_FAILED;
+  return (void *) mapaddr;
 }
 
+check_no_hidden(__fxstat64);
 int weak_function
-__fxstat (int vers, int fd, struct stat *buf)
+__fxstat64 (int vers, int fd, struct stat64 *buf)
 {
   error_t err;
 
@@ -489,9 +523,11 @@ __fxstat (int vers, int fd, struct stat *buf)
 
   return 0;
 }
+libc_hidden_def (__fxstat64)
 
+check_no_hidden(__xstat64);
 int weak_function
-__xstat (int vers, const char *file, struct stat *buf)
+__xstat64 (int vers, const char *file, struct stat64 *buf)
 {
   error_t err;
   mach_port_t port;
@@ -506,20 +542,29 @@ __xstat (int vers, const char *file, struct stat *buf)
 
   return 0;
 }
+libc_hidden_def (__xstat64)
 
 /* This function is called by the dynamic linker (rtld.c) to check
    whether debugging malloc is allowed even for SUID binaries.  This
    stub will always fail, which means that malloc-debugging is always
    disabled for SUID binaries.  */
+check_no_hidden(__access);
 int weak_function
 __access (const char *file, int type)
 {
   errno = ENOSYS;
   return -1;
 }
+check_no_hidden(__access_noerrno);
+int weak_function
+__access_noerrno (const char *file, int type)
+{
+  return -1;
+}
 
+check_no_hidden(__getpid);
 pid_t weak_function
-__getpid ()
+__getpid (void)
 {
   pid_t pid, ppid;
   int orphaned;
@@ -531,28 +576,64 @@ __getpid ()
   return pid;
 }
 
+/* We need this alias to satisfy references from libc_pic.a objects
+   that were affected by the libc_hidden_proto declaration for __getpid.  */
+strong_alias (__getpid, __GI___getpid)
+
 /* This is called only in some strange cases trying to guess a value
    for $ORIGIN for the executable.  The dynamic linker copes with
    getcwd failing (dl-object.c), and it's too much hassle to include
    the functionality here.  (We could, it just requires duplicating or
    reusing getcwd.c's code but using our special lookup function as in
    `open', above.)  */
-char *
-weak_function
+check_no_hidden(__getcwd);
+char *weak_function
 __getcwd (char *buf, size_t size)
 {
   errno = ENOSYS;
   return NULL;
 }
 
-void weak_function
+/* This is used by dl-tunables.c to strdup strings.  We can just make this a
+   mere allocation.  */
+check_no_hidden(__sbrk);
+void *weak_function
+__sbrk (intptr_t increment)
+{
+  vm_address_t addr;
+  __vm_allocate (__mach_task_self (), &addr, increment, 1);
+  return (void *) addr;
+}
+
+check_no_hidden(__strtoul_internal);
+unsigned long int weak_function
+__strtoul_internal (const char *nptr, char **endptr, int base, int group)
+{
+  assert (base == 0 || base == 10);
+  assert (group == 0);
+  return _dl_strtoul (nptr, endptr);
+}
+
+/* We need this alias to satisfy references from libc_pic.a objects
+   that were affected by the libc_hidden_proto declaration for __strtoul_internal.  */
+strong_alias (__strtoul_internal, __GI___strtoul_internal)
+strong_alias (__strtoul_internal, __GI_____strtoul_internal)
+
+check_no_hidden(_exit);
+void weak_function attribute_hidden
 _exit (int status)
 {
   __proc_mark_exit (_dl_hurd_data->portarray[INIT_PORT_PROC],
 		    W_EXITCODE (status, 0), 0);
   while (__task_terminate (__mach_task_self ()))
     __mach_task_self_ = (__mach_task_self) ();
+
+  LOSE;
+  abort ();
 }
+/* We need this alias to satisfy references from libc_pic.a objects
+   that were affected by the libc_hidden_proto declaration for _exit.  */
+strong_alias (_exit, __GI__exit)
 
 /* Try to get a machine dependent instruction which will make the
    program crash.  This is used in case everything else fails.  */
@@ -562,6 +643,7 @@ _exit (int status)
 # define ABORT_INSTRUCTION
 #endif
 
+check_no_hidden(abort);
 void weak_function
 abort (void)
 {
@@ -576,6 +658,14 @@ abort (void)
     /* Try for ever and ever.  */
     ABORT_INSTRUCTION;
 }
+
+/* We need this alias to satisfy references from libc_pic.a objects
+   that were affected by the libc_hidden_proto declaration for abort.  */
+strong_alias (abort, __GI_abort)
+strong_alias (abort, __GI___chk_fail)
+strong_alias (abort, __GI___fortify_fail)
+strong_alias (abort, __GI___assert_fail)
+strong_alias (abort, __GI___assert_perror_fail)
 
 /* This function is called by interruptible RPC stubs.  For initial
    dynamic linking, just use the normal mach_msg.  Since this defn is
@@ -597,35 +687,16 @@ _hurd_intr_rpc_mach_msg (mach_msg_header_t *msg,
 
 
 void
-internal_function
 _dl_show_auxv (void)
 {
   /* There is nothing to print.  Hurd has no auxiliary vector.  */
 }
 
 
-/* Return an array of useful/necessary hardware capability names.  */
-const struct r_strlenpair *
-internal_function
-_dl_important_hwcaps (const char *platform, size_t platform_len, size_t *sz,
-		      size_t *max_capstrlen)
-{
-  struct r_strlenpair *result;
-
-  /* Return an empty array.  Hurd has no hardware capabilities.  */
-  result = (struct r_strlenpair *) malloc (sizeof (*result));
-  if (result == NULL)
-    _dl_signal_error (ENOMEM, NULL, NULL, "cannot create capability list");
-
-  result[0].str = (char *) result;	/* Does not really matter.  */
-  result[0].len = 0;
-
-  *sz = 1;
-  return result;
-}
-
 void weak_function
 _dl_init_first (int argc, ...)
 {
   /* This no-op definition only gets used if libc is not linked in.  */
 }
+
+#endif /* SHARED */
