@@ -1,4 +1,4 @@
-/* Copyright (C) 1991-2015 Free Software Foundation, Inc.
+/* Copyright (C) 1991-2019 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
    The GNU C Library is free software; you can redistribute it and/or
@@ -24,10 +24,7 @@
 /* Change the owner and group of FILE; if it's a link, do the link and
    not the target.  */
 int
-__lchown (file, owner, group)
-     const char *file;
-     uid_t owner;
-     gid_t group;
+__lchown (const char *file, uid_t owner, gid_t group)
 {
   error_t err;
   file_t port = __file_name_lookup (file, O_NOLINK, 0);
