@@ -1,4 +1,4 @@
-/* Copyright (C) 1994-2015 Free Software Foundation, Inc.
+/* Copyright (C) 1994-2019 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
    The GNU C Library is free software; you can redistribute it and/or
@@ -89,8 +89,8 @@ timer_thread (void)
       err = __mach_msg (&msg.header,
 			MACH_RCV_MSG|MACH_RCV_TIMEOUT|MACH_RCV_INTERRUPT,
 			0, 0, _hurd_itimer_port,
-			_hurd_itimerval.it_value.tv_sec * 1000 +
-			_hurd_itimerval.it_value.tv_usec / 1000,
+			_hurd_itimerval.it_value.tv_sec * 1000
+			+ _hurd_itimerval.it_value.tv_usec / 1000,
 			MACH_PORT_NULL);
       switch (err)
 	{
@@ -221,11 +221,12 @@ setitimer_locked (const struct itimerval *new, struct itimerval *old,
 	    goto out;
 	  _hurd_itimer_thread_stack_base = 0; /* Anywhere.  */
 	  _hurd_itimer_thread_stack_size = __vm_page_size; /* Small stack.  */
-	  if (err = __mach_setup_thread (__mach_task_self (),
+	  if ((err = __mach_setup_thread (__mach_task_self (),
 					 _hurd_itimer_thread,
 					 &timer_thread,
 					 &_hurd_itimer_thread_stack_base,
 					 &_hurd_itimer_thread_stack_size))
+	      || (err = __mach_setup_tls(_hurd_itimer_thread)))
 	    {
 	      __thread_terminate (_hurd_itimer_thread);
 	      _hurd_itimer_thread = MACH_PORT_NULL;
@@ -277,8 +278,8 @@ setitimer_locked (const struct itimerval *new, struct itimerval *old,
 	     kernel context so that when the thread is resumed, mach_msg
 	     will return to timer_thread (below) and it will fetch new
 	     values from _hurd_itimerval.  */
-	  if ((err = __thread_suspend (_hurd_itimer_thread)) ||
-	      (err = __thread_abort (_hurd_itimer_thread)))
+	  if ((err = __thread_suspend (_hurd_itimer_thread))
+	      || (err = __thread_abort (_hurd_itimer_thread)))
 	    /* If we can't save it for later, nuke it.  */
 	    kill_itimer_thread ();
 	  else
@@ -286,8 +287,8 @@ setitimer_locked (const struct itimerval *new, struct itimerval *old,
 	}
     }
   /* See if the timeout changed.  If so, we must alert the itimer thread.  */
-  else if (remaining.tv_sec != newval.it_value.tv_sec ||
-	   remaining.tv_usec != newval.it_value.tv_usec)
+  else if (remaining.tv_sec != newval.it_value.tv_sec
+	   || remaining.tv_usec != newval.it_value.tv_usec)
     {
       /* The timeout value is changing.  Tell the itimer thread to
 	 reexamine it and start counting down.  If the itimer thread is
