@@ -1,4 +1,4 @@
-/* Copyright (C) 1991, 1993, 1994, 1995, 1997 Free Software Foundation, Inc.
+/* Copyright (C) 1991-2019 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
    The GNU C Library is free software; you can redistribute it and/or
@@ -24,8 +24,7 @@
 /* Store in SET all signals that are blocked and pending.  */
 /* XXX should be __sigpending ? */
 int
-sigpending (set)
-     sigset_t *set;
+sigpending (sigset_t *set)
 {
   struct hurd_sigstate *ss;
   sigset_t pending;
