@@ -1,5 +1,5 @@
 /* Multiple versions of ceilf.
-   Copyright (C) 2013-2015 Free Software Foundation, Inc.
+   Copyright (C) 2013-2019 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
    The GNU C Library is free software; you can redistribute it and/or
@@ -16,10 +16,12 @@
    License along with the GNU C Library; if not, see
    <http://www.gnu.org/licenses/>.  */
 
+#define NO_MATH_REDIRECT
 #include <math.h>
 #include <math_ldbl_opt.h>
 #include <shlib-compat.h>
 #include "init-arch.h"
+#include <libm-alias-float.h>
 
 extern __typeof (__ceilf) __ceilf_ppc32 attribute_hidden;
 extern __typeof (__ceilf) __ceilf_power5plus attribute_hidden;
@@ -29,4 +31,4 @@ libc_ifunc (__ceilf,
 	    ? __ceilf_power5plus
             : __ceilf_ppc32);
 
-weak_alias (__ceilf, ceilf)
+libm_alias_float (__ceil, ceil)
