@@ -1,4 +1,4 @@
-/* Copyright (C) 2002-2015 Free Software Foundation, Inc.
+/* Copyright (C) 2002-2019 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
    Contributed by Ulrich Drepper <drepper@redhat.com>, 2002.
 
@@ -18,13 +18,11 @@
 
 #include <pthread.h>
 #include <stdio.h>
-#include <libio.h>
-#include <bits/stdio-lock.h>
+#include <stdio-lock.h>
 
 
 void
-__funlockfile (stream)
-     FILE *stream;
+__funlockfile (FILE *stream)
 {
   _IO_lock_unlock (*stream->_lock);
 }
