@@ -1,5 +1,5 @@
 /* Store current floating-point environment and clear exceptions.
-   Copyright (C) 2000-2017 Free Software Foundation, Inc.
+   Copyright (C) 2000-2019 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
    Contributed by Denis Joseph Barrow (djbarrow@de.ibm.com).
 
@@ -24,7 +24,7 @@ int __feholdexcept (fenv_t *envp)
 {
   fexcept_t fpc;
   /* Store the environment.  */
-  fegetenv (envp);
+  __fegetenv (envp);
   /* Clear the current sticky bits as more than one exception
      may be generated.  */
   fpc = envp->__fpc & ~(FPC_FLAGS_MASK | FPC_DXC_MASK);
