@@ -20,9 +20,9 @@
 #include <elision-conf.h>
 #include "lowlevellock.h"
 
-#define __lll_lock_elision __lll_timedlock_elision
-#define EXTRAARG const struct timespec *t,
+#define __lll_lock_elision __lll_clocklock_elision
+#define EXTRAARG clockid_t clockid, const struct timespec *t,
 #undef LLL_LOCK
-#define LLL_LOCK(a, b) lll_timedlock(a, t, b)
+#define LLL_LOCK(a, b) lll_clocklock(a, clockid, t, b)
 
 #include "elision-lock.c"
