@@ -1,5 +1,5 @@
 /* elision-trylock.c: Lock eliding trylock for pthreads.
-   Copyright (C) 2015-2018 Free Software Foundation, Inc.
+   Copyright (C) 2015-2019 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
    The GNU C Library is free software; you can redistribute it and/or
@@ -30,7 +30,6 @@
 int
 __lll_trylock_elision (int *futex, short *adapt_count)
 {
-#ifndef __SPE__
   /* Implement POSIX semantics by forbiding nesting elided trylocks.  */
   __libc_tabort (_ABORT_NESTED_TRYLOCK);
 
@@ -66,6 +65,5 @@ __lll_trylock_elision (int *futex, short *adapt_count)
     }
 
 use_lock:
-#endif
   return lll_trylock (*futex);
 }
