@@ -1,4 +1,4 @@
-/* Copyright (C) 1998-2018 Free Software Foundation, Inc.
+/* Copyright (C) 1998-2019 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
    The GNU C Library is free software; you can redistribute it and/or
@@ -73,25 +73,11 @@ __libc_start_main (int argc, char **argv,
 
   /* Initialize the __cache_line_size variable from the aux vector.  For the
      static case, we also need _dl_hwcap, _dl_hwcap2 and _dl_platform, so we
-     can call __tcb_parse_hwcap_and_convert_at_platform ().
-
-     This is used by memset to optimize setting to zero.  We have to
-     detect 8xx processors, which have buggy dcbz implementations that
-     cannot report page faults correctly.  That requires reading SPR,
-     which is a privileged operation.  Fortunately 2.2.18 and later
-     emulates PowerPC mfspr reads from the PVR register.  */
+     can call __tcb_parse_hwcap_and_convert_at_platform ().  */
   for (ElfW (auxv_t) * av = auxvec; av->a_type != AT_NULL; ++av)
     switch (av->a_type)
       {
       case AT_DCACHEBSIZE:
-	if (__LINUX_KERNEL_VERSION >= 0x020218)
-	  {
-	    unsigned pvr = 0;
-
-	    asm ("mfspr %0, 287" : "=r" (pvr) :);
-	    if ((pvr & 0xffff0000) == 0x00500000)
-	      break;
-	  }
 	__cache_line_size = av->a_un.a_val;
 	break;
 #ifndef SHARED
