@@ -1,4 +1,4 @@
-/* Copyright (C) 2011-2015 Free Software Foundation, Inc.
+/* Copyright (C) 2011-2019 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
    Contributed by Ryan S. Arnold <rsa@us.ibm.com>, 2011.
 
@@ -17,8 +17,10 @@
    <http://www.gnu.org/licenses/>.  */
 
 #include <fcntl.h>
+#include <limits.h>
 #include <paths.h>
 #include <stdio.h>
+#include <stdint.h>
 #include <stdlib.h>
 #include <unistd.h>
 #include <sys/uio.h>
@@ -108,8 +110,5 @@ do_test (void)
   return 0;
 }
 
-/* Time enough for a large writev syscall to complete.  */
-#define TIMEOUT 20
-
 #define TEST_FUNCTION do_test ()
 #include "../test-skeleton.c"
