@@ -1,4 +1,4 @@
-/* Copyright (C) 1995-2015 Free Software Foundation, Inc.
+/* Copyright (C) 1995-2019 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
    Contributed by Ulrich Drepper <drepper@gnu.ai.mit.edu>, August 1995.
 
@@ -22,10 +22,7 @@
 /* Provide operations to control over shared memory segments.  */
 
 int
-shmctl (shmid, cmd, buf)
-     int shmid;
-     int cmd;
-     struct shmid_ds *buf;
+shmctl (int shmid, int cmd, struct shmid_ds *buf)
 {
   __set_errno (ENOSYS);
   return -1;
