@@ -1,4 +1,4 @@
-/* Copyright (C) 1998-2017 Free Software Foundation, Inc.
+/* Copyright (C) 1998-2019 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
    Contributed by Ulrich Drepper <drepper@cygnus.com>, 1998.
 
@@ -38,19 +38,18 @@ extern const struct gconv_fcts __wcsmbs_gconv_fcts_c attribute_hidden;
 
 /* Load conversion functions for the currently selected locale.  */
 extern void __wcsmbs_load_conv (struct __locale_data *new_category)
-     internal_function;
+     attribute_hidden;
 
 /* Clone the current `__wcsmbs_load_conv' value.  */
 extern void __wcsmbs_clone_conv (struct gconv_fcts *copy)
-     internal_function;
+     attribute_hidden;
 
 /* Find the conversion functions for converting to and from NAME.  */
 extern int __wcsmbs_named_conv (struct gconv_fcts *copy, const char *name)
-     internal_function;
+     attribute_hidden;
 
 /* Function used for the `private.cleanup' hook.  */
-extern void _nl_cleanup_ctype (struct __locale_data *)
-     internal_function attribute_hidden;
+extern void _nl_cleanup_ctype (struct __locale_data *) attribute_hidden;
 
 
 #include <iconv/gconv_int.h>
