@@ -1,4 +1,4 @@
-/* Copyright (C) 1996-2000, 2002, 2003 Free Software Foundation, Inc.
+/* Copyright (C) 1996-2019 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
    Contributed by Ulrich Drepper <drepper@gnu.org>, 1996.
 
@@ -13,10 +13,10 @@
    Lesser General Public License for more details.
 
    You should have received a copy of the GNU Lesser General Public
-   License along with the GNU C Library; if not, write to the Free
-   Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
-   02111-1307 USA.  */
+   License along with the GNU C Library; if not, see
+   <http://www.gnu.org/licenses/>.  */
 
+#include <assert.h>
 #include <dlfcn.h>
 #include <errno.h>
 #include <stdlib.h>
@@ -24,7 +24,7 @@
 #include <wchar.h>
 #include <wcsmbsload.h>
 
-#include <assert.h>
+#include <sysdep.h>
 
 #ifndef EILSEQ
 # define EILSEQ EINVAL
@@ -35,11 +35,7 @@
 static mbstate_t state;
 
 size_t
-__wcsrtombs (dst, src, len, ps)
-     char *dst;
-     const wchar_t **src;
-     size_t len;
-     mbstate_t *ps;
+__wcsrtombs (char *dst, const wchar_t **src, size_t len, mbstate_t *ps)
 {
   struct __gconv_step_data data;
   int status;
@@ -52,13 +48,17 @@ __wcsrtombs (dst, src, len, ps)
   data.__internal_use = 1;
   data.__flags = __GCONV_IS_LAST;
   data.__statep = ps ?: &state;
-  data.__trans = NULL;
 
   /* Get the conversion functions.  */
   fcts = get_gconv_fcts (_NL_CURRENT_DATA (LC_CTYPE));
 
   /* Get the structure with the function pointers.  */
   tomb = fcts->tomb;
+  __gconv_fct fct = tomb->__fct;
+#ifdef PTR_DEMANGLE
+  if (tomb->__shlib_handle != NULL)
+    PTR_DEMANGLE (fct);
+#endif
 
   /* We have to handle DST == NULL special.  */
   if (dst == NULL)
@@ -79,10 +79,9 @@ __wcsrtombs (dst, src, len, ps)
 	{
 	  data.__outbuf = buf;
 
-	  status = DL_CALL_FCT (tomb->__fct,
-				(tomb, &data, &inbuf,
-				 (const unsigned char *) srcend, NULL,
-				 &dummy, 0, 1));
+	  status = DL_CALL_FCT (fct, (tomb, &data, &inbuf,
+				      (const unsigned char *) srcend, NULL,
+				      &dummy, 0, 1));
 
 	  /* Count the number of bytes.  */
 	  result += data.__outbuf - buf;
@@ -105,13 +104,12 @@ __wcsrtombs (dst, src, len, ps)
       const wchar_t *srcend = *src + __wcsnlen (*src, len) + 1;
       size_t dummy;
 
-      data.__outbuf = dst;
-      data.__outbufend = dst + len;
+      data.__outbuf = (unsigned char *) dst;
+      data.__outbufend = (unsigned char *) dst + len;
 
-      status = DL_CALL_FCT (tomb->__fct,
-			    (tomb, &data, (const unsigned char **) src,
-			     (const unsigned char *) srcend, NULL,
-			     &dummy, 0, 1));
+      status = DL_CALL_FCT (fct, (tomb, &data, (const unsigned char **) src,
+				  (const unsigned char *) srcend, NULL,
+				  &dummy, 0, 1));
 
       /* Count the number of bytes.  */
       result = data.__outbuf - (unsigned char *) dst;
