@@ -1,4 +1,4 @@
-/* Copyright (C) 1996-2017 Free Software Foundation, Inc.
+/* Copyright (C) 1996-2019 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
    Contributed by Ulrich Drepper <drepper@gnu.ai.mit.edu>, 1996.
 
@@ -22,7 +22,4 @@
 
 #define	USE_WIDE_CHAR	1
 
-extern double ____wcstod_l_internal (const wchar_t *, wchar_t **, int,
-				     locale_t);
-
 #include <stdlib/strtod.c>
