@@ -1,5 +1,5 @@
 /* Convert string representing a number to integer value, using given locale.
-   Copyright (C) 1997-2017 Free Software Foundation, Inc.
+   Copyright (C) 1997-2019 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
    Contributed by Ulrich Drepper <drepper@cygnus.com>, 1997.
 
@@ -23,7 +23,4 @@
 
 #define	USE_WIDE_CHAR	1
 
-extern float ____wcstof_l_internal (const wchar_t *, wchar_t **, int,
-				    locale_t);
-
 #include <stdlib/strtof_l.c>
